"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeEventListener = exports.addEventListenerOnce = exports.addEventListener = exports.requestAnimationFrame = exports.isMobile = exports.isServer = void 0;
exports.isServer = typeof window === 'undefined';
exports.isMobile = !exports.isServer && /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator === null || navigator === void 0 ? void 0 : navigator.userAgent);
exports.requestAnimationFrame = !exports.isServer
    ? window.mozRequestAnimationFrame
        || window.requestAnimationFrame
        || window.webkitRequestAnimationFrame
        || window.oRequestAnimationFrame
        || window.msRequestAnimationFrame
        || ((callback) => { window.setTimeout(callback, 1000 / 60); })
    : () => { };
/**
 * Attaches events to the given element.
 */
const addEventListener = (el, events, callback, options = true) => {
    for (const i in events) {
        el.addEventListener(events[i], callback, options);
    }
};
exports.addEventListener = addEventListener;
/**
 * Attaches events to the given element for once.
 */
const addEventListenerOnce = (el, events, callback, addOptions = true, removeOptions = true) => {
    const cb = (e) => {
        (0, exports.removeEventListener)(el, events, cb, removeOptions);
        callback(e);
    };
    (0, exports.addEventListener)(el, events, cb, addOptions);
};
exports.addEventListenerOnce = addEventListenerOnce;
/**
 * Removes events from the given element.
 */
const removeEventListener = (el, events, callback, options = true) => {
    for (const i in events) {
        el.removeEventListener(events[i], callback, options);
    }
};
exports.removeEventListener = removeEventListener;
